==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/PolicyAuditConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class PolicyAuditConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigFluent<A>{
  public PolicyAuditConfigFluentImpl() {
  }
  public PolicyAuditConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig instance) {
    this.withDestination(instance.getDestination()); 
    this.withMaxFileSize(instance.getMaxFileSize()); 
    this.withRateLimit(instance.getRateLimit()); 
    this.withSyslogFacility(instance.getSyslogFacility()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String destination;
  private java.lang.Integer maxFileSize;
  private java.lang.Integer rateLimit;
  private java.lang.String syslogFacility;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDestination() {
    return this.destination;
  }
  public A withDestination(java.lang.String destination) {
    this.destination=destination; return (A) this;
  }
  public java.lang.Boolean hasDestination() {
    return this.destination != null;
  }
  
  /**
   * Method is deprecated. use withDestination instead.
   */
  @java.lang.Deprecated
  public A withNewDestination(java.lang.String arg0) {
    return (A)withDestination(new String(arg0));
  }
  public java.lang.Integer getMaxFileSize() {
    return this.maxFileSize;
  }
  public A withMaxFileSize(java.lang.Integer maxFileSize) {
    this.maxFileSize=maxFileSize; return (A) this;
  }
  public java.lang.Boolean hasMaxFileSize() {
    return this.maxFileSize != null;
  }
  public java.lang.Integer getRateLimit() {
    return this.rateLimit;
  }
  public A withRateLimit(java.lang.Integer rateLimit) {
    this.rateLimit=rateLimit; return (A) this;
  }
  public java.lang.Boolean hasRateLimit() {
    return this.rateLimit != null;
  }
  public java.lang.String getSyslogFacility() {
    return this.syslogFacility;
  }
  public A withSyslogFacility(java.lang.String syslogFacility) {
    this.syslogFacility=syslogFacility; return (A) this;
  }
  public java.lang.Boolean hasSyslogFacility() {
    return this.syslogFacility != null;
  }
  
  /**
   * Method is deprecated. use withSyslogFacility instead.
   */
  @java.lang.Deprecated
  public A withNewSyslogFacility(java.lang.String arg0) {
    return (A)withSyslogFacility(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PolicyAuditConfigFluentImpl that = (PolicyAuditConfigFluentImpl) o;
    if (destination != null ? !destination.equals(that.destination) :that.destination != null) return false;
    if (maxFileSize != null ? !maxFileSize.equals(that.maxFileSize) :that.maxFileSize != null) return false;
    if (rateLimit != null ? !rateLimit.equals(that.rateLimit) :that.rateLimit != null) return false;
    if (syslogFacility != null ? !syslogFacility.equals(that.syslogFacility) :that.syslogFacility != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(destination,  maxFileSize,  rateLimit,  syslogFacility,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/PolicyAuditConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class PolicyAuditConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfigFluent<A>{
  public PolicyAuditConfigFluentImpl() {
  }
  public PolicyAuditConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.PolicyAuditConfig instance) {
    this.withDestination(instance.getDestination()); 
    this.withMaxFileSize(instance.getMaxFileSize()); 
    this.withRateLimit(instance.getRateLimit()); 
    this.withSyslogFacility(instance.getSyslogFacility()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String destination;
  private java.lang.Integer maxFileSize;
  private java.lang.Integer rateLimit;
  private java.lang.String syslogFacility;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDestination() {
    return this.destination;
  }
  public A withDestination(java.lang.String destination) {
    this.destination=destination; return (A) this;
  }
  public java.lang.Boolean hasDestination() {
    return this.destination != null;
  }
  
  /**
   * Method is deprecated. use withDestination instead.
   */
  @java.lang.Deprecated
  public A withNewDestination(java.lang.String arg0) {
    return (A)withDestination(new String(arg0));
  }
  public java.lang.Integer getMaxFileSize() {
    return this.maxFileSize;
  }
  public A withMaxFileSize(java.lang.Integer maxFileSize) {
    this.maxFileSize=maxFileSize; return (A) this;
  }
  public java.lang.Boolean hasMaxFileSize() {
    return this.maxFileSize != null;
  }
  public java.lang.Integer getRateLimit() {
    return this.rateLimit;
  }
  public A withRateLimit(java.lang.Integer rateLimit) {
    this.rateLimit=rateLimit; return (A) this;
  }
  public java.lang.Boolean hasRateLimit() {
    return this.rateLimit != null;
  }
  public java.lang.String getSyslogFacility() {
    return this.syslogFacility;
  }
  public A withSyslogFacility(java.lang.String syslogFacility) {
    this.syslogFacility=syslogFacility; return (A) this;
  }
  public java.lang.Boolean hasSyslogFacility() {
    return this.syslogFacility != null;
  }
  
  /**
   * Method is deprecated. use withSyslogFacility instead.
   */
  @java.lang.Deprecated
  public A withNewSyslogFacility(java.lang.String arg0) {
    return (A)withSyslogFacility(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PolicyAuditConfigFluentImpl that = (PolicyAuditConfigFluentImpl) o;
    if (destination != null ? !destination.equals(that.destination) :that.destination != null) return false;
    if (maxFileSize != null ? !maxFileSize.equals(that.maxFileSize) :that.maxFileSize != null) return false;
    if (rateLimit != null ? !rateLimit.equals(that.rateLimit) :that.rateLimit != null) return false;
    if (syslogFacility != null ? !syslogFacility.equals(that.syslogFacility) :that.syslogFacility != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(destination,  maxFileSize,  rateLimit,  syslogFacility,  additionalProperties,  super.hashCode());
  }
  
}
